==> dimples-0.0.5.tar.gz: dimples-0.0.5/dimples/client/__init__.py <==
# -*- coding: utf-8 -*-
# ==============================================================================
# MIT License
#
# Copyright (c) 2019 Albert Moky
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
# ==============================================================================

"""
    Client Module
    ~~~~~~~~~~~~~

"""

from .cpu import *

from .session import ClientSession
from .state import SessionState

from .processor import ClientProcessor, ClientContentProcessorCreator
from .messenger import ClientMessenger
from .terminal import Terminal


__all__ = [

    #
    #   CPU
    #
    'HandshakeCommandProcessor',
    'LoginCommandProcessor',
    'ReceiptCommandProcessor',

    #
    #   Client
    #
    'ClientSession', 'SessionState',

    'ClientProcessor', 'ClientContentProcessorCreator',
    'ClientMessenger',
    'Terminal',
]

==> dimples-0.1.2.tar.gz: dimples-0.1.2/dimples/client/__init__.py <==
# -*- coding: utf-8 -*-
# ==============================================================================
# MIT License
#
# Copyright (c) 2019 Albert Moky
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
# ==============================================================================

"""
    Client Module
    ~~~~~~~~~~~~~

"""

from .cpu import *

from .session import ClientSession
from .state import SessionState

from .messenger import ClientMessenger
from .packer import ClientMessagePacker
from .processor import ClientMessageProcessor, ClientContentProcessorCreator
from .terminal import Terminal


__all__ = [

    #
    #   CPU
    #
    'HandshakeCommandProcessor',
    'LoginCommandProcessor',
    'ReceiptCommandProcessor',

    #
    #   Client
    #
    'ClientSession', 'SessionState',

    'ClientMessenger',
    'ClientMessagePacker',
    'ClientMessageProcessor', 'ClientContentProcessorCreator',
    'Terminal',
]
